@@ -33,8 +33,8 @@ use vars qw($VERSION $REVISION $GOT_SSL $GOT_CLIENT_DNS);
 # Load the plugin stuff
 use POE::Component::IRC::Plugin qw( :ALL );
 
-$VERSION = '4.86';
-$REVISION = do {my@r=(q$Revision: 142 $=~/\d+/g);sprintf"%d"."%04d"x$#r,@r};
+$VERSION = '4.87';
+$REVISION = do {my@r=(q$Revision: 152 $=~/\d+/g);sprintf"%d"."%04d"x$#r,@r};
 
 # BINGOS: I have bundled up all the stuff that needs changing for inherited classes
 # 	  into _create. This gets called from 'spawn'.
@@ -143,6 +143,7 @@ sub _create {
 				      kick
 				      register
 				      register_session
+				      remove
 				      shutdown
 				      sl
 				      sl_login
@@ -1110,6 +1111,21 @@ sub kick {
   undef;
 }
 
+# Tell the IRC server to forcibly remove a user from a channel. Freenode extension
+sub remove {
+  my ($kernel, $chan, $nick) = @_[KERNEL, ARG0, ARG1];
+  my $message = join '', @_[ARG2 .. $#_];
+
+  unless (defined $chan and defined $nick) {
+    warn "The POE::Component::IRC event \"remove\" requires at least two arguments";
+    return;
+  }
+
+  $nick .= " :$message" if defined $message;
+  $kernel->yield( 'sl_high', "REMOVE $chan $nick" );
+  undef;
+}
+
 # Set up a new IRC component. Deprecated.
 sub new {
   my ($package, $alias) = splice @_, 0, 2;
@@ -2315,6 +2331,13 @@ channel. Takes at least 2 arguments: a channel name, the nick of the
 user to boot, and an optional witty message to show them as they sail
 out the door.
 
+=item remove ( Freenode only )
+
+Tell the IRC server to forcibly evict a user from a particular
+channel. Takes at least 2 arguments: a channel name, the nick of the
+user to boot, and an optional witty message to show them as they sail
+out the door. Similar to KICK but does an enforced PART instead.
+
 =item mode
 
 Request a mode change on a particular channel or user. Takes at least
